/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

interface PartnerProperties {
  readonly name:         string;
  readonly avatar:       string;
  readonly relationship: string;
  readonly url:          string;
  readonly anniversary:  Date;
}

/**
 * Renders the view for a polycule member.
 * @param properties - The member to render.
 * @returns A JSX element.
 */
export const Partner = (properties: PartnerProperties): JSX.Element => {
  const { name, avatar, relationship, url, anniversary } = properties;

  return (
    <div className="flex items-start gap-2.5 pb-10 w-full">
      <Image
        alt={`${name}'s avatar.`}
        className="rounded-full"
        height={75}
        src={`https://cdn.nhcarrigan.com/avatars/${avatar}`}
        width={75}
      />
      <div className="flex flex-col w-full leading-1.5 p-4
        border-gray-200 bg-gray-100 rounded-e-xl
        rounded-es-xl dark:bg-gray-700">
        <div>
          <a
            className="text-sm font-semibold text-[#abfcec]"
            href={url}
            target="noopener noreferrer"
          >
            {name}
          </a>
          <p className="text-sm font-normal text-gray-500 dark:text-gray-400">
            {anniversary.toLocaleDateString("en-GB", {
              day:   "numeric",
              month: "long",
              year:  "numeric",
            })}
          </p>
        </div>
        <p className="text-sm font-normal py-2.5 text-gray-900 dark:text-white">
          {relationship}
        </p>
      </div>
    </div>
  );
};
